==> quassel_0.3.0.orig.tar.gz: quassel-0.3.0/src/core/sessionthread.h <==
/***************************************************************************
 *   Copyright (C) 2005-08 by the Quassel IRC Team                         *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef _SESSIONTHREAD_H_
#define _SESSIONTHREAD_H_

#include <QMutex>
#include <QThread>

#include "types.h"

class CoreSession;
class QIODevice;

class SessionThread : public QThread {
  Q_OBJECT

  public:
    SessionThread(UserId user, bool restoreState, QObject *parent = 0);
    ~SessionThread();

    void run();

    CoreSession *session();
    UserId user();

  public slots:
    void addClient(QIODevice *socket);

  private slots:
    void setSessionInitialized();

  signals:
    void initialized();
    void shutdown();

  private:
    CoreSession *_session;
    UserId _user;
    QList<QIODevice *> clientQueue;
    bool _sessionInitialized;
    bool _restoreState;

    bool isSessionInitialized();
    void addClientToSession(QIODevice *socket);
};

#endif

==> quassel_0.13.1.orig.tar.gz: quassel-0.13.1/src/core/sessionthread.h <==
/***************************************************************************
 *   Copyright (C) 2005-2019 by the Quassel Project                        *
 *   devel@quassel-irc.org                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) version 3.                                           *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#pragma once

#include <memory>

#include <QThread>

#include "types.h"

class CoreSession;
class Peer;
class InternalPeer;
class RemotePeer;

class SessionThread : public QObject
{
    Q_OBJECT

public:
    SessionThread(UserId user, bool restoreState, bool strictIdentEnabled, QObject *parent = 0);
    ~SessionThread();

public slots:
    void addClient(Peer *peer);
    void shutdown();

private slots:
    void onSessionInitialized();
    void onSessionDestroyed();

signals:
    void initialized();
    void shutdownSession();
    void shutdownComplete(SessionThread *);

    void addClientToWorker(Peer *peer);

private:
    QThread _sessionThread;
    bool _sessionInitialized{false};

    std::vector<Peer *> _clientQueue;
};
